<?php
class Osoba
{
  protected $dane = array('imie' => "", 'nazwisko' => '');
  public function ustawImie($imie)
  {
    $this->dane['imie'] = $imie;
  }
  public function ustawNazwisko($nazwisko)
  {
    $this->dane['nazwisko'] = $nazwisko;
  }
  public function pobierzImie()
  {
    return $this->dane['imie'];
  }
  public function pobierzNazwisko()
  {
    return $this->dane['nazwisko'];
  }
}
?>
