<?php
include "osoba.php";
include "uzytkownik.php";

$osoba = new Osoba();

$osoba->ustawImie("Andrzej");
$osoba->ustawNazwisko("Nowak");

echo "Dane obiektu \$osoba\n";
echo $osoba->pobierzImie(), "\n";
echo $osoba->pobierzNazwisko(), "\n";

$uzytkownik = new Uzytkownik();

$uzytkownik->ustawImie("Jan");
$uzytkownik->ustawNazwisko("Kowalski");
$uzytkownik->ustawId("012");

echo "\nDane obiektu \$uzytkownik\n";
echo $uzytkownik->pobierzImie(), "\n";
echo $uzytkownik->pobierzNazwisko(), "\n";
echo $uzytkownik->pobierzId(), "\n";
?>
